@@ -40,12 +40,18 @@ lidar_search <- function(bbox,
   if (missing(bbox)) {
     stop("Please define a bbox")
   }
+  result <- NULL
   tryCatch(
     result <- return_response(bbox, max_return),
     error = function(e) {
-      return(e)
+      return(NULL)
     }
   )
+
+  if (is.null(result)) {
+    return(invisible(NULL))
+  }
+
   num <- length(result[,1])
   original_timeout <- getOption('timeout')
   original_par <- par(no.readonly = TRUE)
